
It is important for a language community to design its own rubric. When a language community establishes its own standards, it fosters ownership of a project. 

During the first few days of a MAST workshop, the facilitator guides a translation team through the process of developing a rubric for assessing the quality of their translation. Below are the steps used to create a rubric to guide quality assurance throughout the project. 

1. The translation team will choose a leader/representative of their language group to manage the rubric building process. If this leader/representative does not speak a language that the facilitator understands, the team will choose someone to translate the rubric for the facilitator.

2. The individuals on the team will independently answer the following questions: 

    * What is a good translation?   
    * What are at least ten qualities of a good translation? 

3. The translation team will then work together to make one list that includes all the items from each individual’s list. The leader/representative will combine the qualities that are the same and develop one master list of around 10 qualities. 

4.	If the facilitator or anyone else at the event is familiar with Bible translation rubrics, he may review the team's rubric. If he sees that something important is missing in their rubric, he may ask questions of the group to help them to recognize other qualities that would be beneficial for their translation to have. 

    If there is no one at the event who is familiar with Bible translation rubrics, the team can compare their rubric with sample rubrics. Some examples can be found at v-raft.com. The following are questions that may help them decide whether or not to make any changes to their rubric:

    * Are there qualities in any of those rubrics that you would like to add to your own? 
    * Are there any qualities in your own that you now think may not be very important?  

5.	The team will have a discussion and agree on the qualities to include in their rubric. There should be about 10 qualities.

6.	The team will verbally define each of the qualities established in the rubric and then record the definitions. Each definition should be clear enough that anyone from that language group could use the rubric and understand the qualities the team wants their translation to have.

7. The team will create a list of things the translation needs in order for it to have each of those characteristics. 

8. The team will make each item in this list into a question with a yes or no response.

9. The team should make sure that the rubric is clear enough that if a person who speaks the language were to later check a translated chapter, they could pick up that chapter, take the rubric and the source text, and determine whether the standards established in the rubric were met.
 
10.	Finally, now is a good time for the team to discuss the following:  
 
    * After the translation project is completed, how would you answer someone who asks, "Is this translation of good quality?"  They should realize that if all of these standards established in the rubric are met, then the translation they have been working on will be a good quality translation.

11.	When possible, the team will translate the rubric into English and share it at [v-raft.com](https://v-raft.com).


### Example of Creating a Rubric
Below you will see an example of how a rubric was created by following steps 2-8 above. (Steps involving individual work or discussion are not shown.)

#### Step 3: The group's combined list of characteristics

  * Accurate  
  * Community Oriented  
  * Clear  
  * Grammatically consistent  
  * Natural  
  * Faithful to Original Languages  
  * Authoritative  
  * Historical  
  * Equal  
  * Acceptable  
  * Trustworthy  
  * Has Appropriate Familial Terms for God the Father and his Son
  * Culturally Relevant
  * Uses traditional words rather than the ones kids use
  * Theologically accurate
  * Uses a certain name for God
  * Is easy for non-believers to understand
  * Is easy for children to understand
  * Does not create too many new words 
  * Does not use too many words from the gateway language
  * Can be used by pastors to build up the church


#### Steps 3 - 5: Condense the characteristics and settle on around 10 characteristics. 

  * Accurate
  * Style
  * Clear
  * Natural
  * Faithful
  * Authoritative
  * Historical

Notice that in condensing the qualities, some of the items on the list are combined so there are no longer 10 separate qualities. Also after discussion, the team decided not to include some qualities, because they pertained to community acceptance and not the quality of the translation itself or because they were qualities for a type of Bible the team did not want to produce. 

#### Step 6: Define the characteristics

  * Accurate - The translation says the same thing as the source text.
  * Style - The translation uses the same style as the source text.
  * Clear - People can understand what the translation says.
  * Natural - The translation sounds like the way we speak.
  * Faithful - The translation does not unnecessarily favor one opinion over another.
  * Authoritative - The translation can be recognized to be from God.
  * Historical - The translation does not make people think it is about people in my culture.

#### Step 7: List what the translation needs in order for it to have each of the characteristics.

**Accurate**   

1. Key words are translated accurately.
2. Nothing is added or missing from the text.
3. The text reflects the author's intended meaning. 

**Style**   
1. The text uses the same style of writing as the source text. For example, poems in the source text are poems in the translated text. Accounts of historical events are translated as historical events.
2. In prophecy, images are not explained for the reader unless the original author explained it.  

**Clear**  
1. The text is understood by a wide range of audiences.  
2. The text uses common language.  
3. The text uses proper language structures (word order, tenses, sentence structure).
4. The punctuation is correct.

**Natural**  
1. The text sounds like how we speak. It uses common language .
2. The text sounds beautiful.
3. The text is efficient and effective in its communication.

**Faithful**  
1. The text does not favor a particular denomination’s understanding of scripture. 
2. The text does not favor one person’s or one group of people’s opinion over another.
3. The text does not promote false doctrine.
4. The text uses proper familial terms for God the Father and his Son.

**Authoritative**  
1. The translation is based on a good source text.  
2. The text does not use language that people think is beneath God. 
3. The text does not use language that is too informal.

**Historical**  
1. The translation does not appear to take place in my community.
2. The names of people and places are not replaced with names of people and places in my community. 
3. The translation describes historical events the way the source text describes them. 

#### Step 8. Make each item in this list into a question with a yes or no response.

**Accurate**  
1. Are the key words translated accurately?  
2. Is nothing added or missing from the text?  
3. Does the text reflect the author's intended meaning?  

**Style**   
1. Does the text use the same style of writing as the source text?
2. In prophecy, does the text avoid explaining images for the reader unless the original author explained it?

**Clear**  
1. Can a wide range of audiences understand the text?  
2. Does the text use common language?
3. Does the text use proper language structures (word order, tenses, sentence structure)?
4. Is the punctuation correct?
    
**Natural**  
1. Does the text sound the same way people speak when using common language?  
2. Does the text sound beautiful?
3. Is the text efficient and effective in its communication?
    
**Faithful**  
1. Does the text avoid favoring a particular denomination’s understanding of scripture?
2. Does the text avoid favoring one person’s or one group of people’s opinion over another?
3. Does the text avoid promoting false doctrine?
4. Does the text use proper familial terms for God the Father and his Son?
    
**Authoritative**  
1. Is the translation based on a good source text?  
2. Does the text avoid using language that people think is beneath God? 
3. Does the text avoid using language that is too informal?
    
**Historical**  
1. Does the translation avoid appearing to take place in my community?
2. Does the translation avoid replacing names of people and places with names of people and places in my community?
3. Does the  translation describe historical events the way the source text describes them?

The questions are designed as yes/no questions. If the answer is “no” to any portion of the scripture (that is, any word, phrase, sentence, paragraph, chapter, or book), then that  portion needs to be reviewed and edited.
