# Markdown Format

## Headings

Headings from `h1` through `h4` are constructed with a `#` for each level. So a 'h1' heading will have one # sign at the beginning of the line and a 'h3' heading will have three # signs at the beginning of the line and so on. The topics in translationAcademy uses only the 'h2' through 'h4' headings.


### The 'h3' heading (three # signs) is used for the following sections: 
Description - Example from the Bible - Translation Strategies - Translation Strategies Examples
#### The 'h4' heading (four # signs) is used for the following section:
Reasons this is a translation issue

## Format Text

### Bold
Use two asterisks (hold down the shift key and press the number 8 key twice) for emphasizing a snippet of text with a heavier font-weight.

``` markdown
The following snippet of text is **rendered as bold text**.
```
The following snippet of text is **rendered as bold text**.


### Italics
Use a single underline (hold down the shift key and press the long and short line key once) for emphasizing a snippet of text with italics.

``` markdown
The following snippet of text is _rendered as italicized text_.
```
The following snippet of text is _rendered as italicized text_.


## Poetry
Place 2 spaces at the end of the line to create a soft linebreak

For example the typist pressed the "Enter" key after this word
and added no spaces - so the text is all on one line.

But here the typist added two spaces before  
pressing the "Enter" key - so the text is on two lines. 

## Biblical References
All biblical references or quotes, are set apart with a vertical line.  This is known as a blockquote.

For quoting blocks of text from the Bible within your document.

Add `>` before any text you want to quote. 

``` markdown
Add `>` before any text you want to quote. 
```

### When there are two biblical references after each other

``` markdown
Sometimes there are two biblical references together. To add a blank line between two references, use:
<blockquote>  at the beginning of the second biblical reference text and
</blockquote>  
> after the end of the second biblical reference text.
```
Displays as:  

Sometimes there are two biblical references together. To add a blank line between two references, use:
<blockquote>  at the beginning of the second biblical reference text and
</blockquote>  
> after the end of the second biblical reference text.


### Nested biblical reference
Biblical references can also be nested:

``` markdown
> Donec massa lacus, ultricies a ullamcorper in, fermentum sed augue. 
Nunc augue augue, aliquam non hendrerit ac, commodo vel nisi. 
>> Sed adipiscing elit vitae augue consectetur a gravida nunc vehicula. Donec auctor 
odio non est accumsan facilisis. Aliquam id turpis in dolor tincidunt mollis ac eu diam.
>>> Donec massa lacus, ultricies a ullamcorper in, fermentum sed augue. 
Nunc augue augue, aliquam non hendrerit ac, commodo vel nisi. 
```
Displays as:

> Donec massa lacus, ultricies a ullamcorper in, fermentum sed augue. 
Nunc augue augue, aliquam non hendrerit ac, commodo vel nisi. 
>> Sed adipiscing elit vitae augue consectetur a gravida nunc vehicula. Donec auctor 
odio non est accumsan facilisis. Aliquam id turpis in dolor tincidunt mollis ac eu diam.
>>> Donec massa lacus, ultricies a ullamcorper in, fermentum sed augue. 
Nunc augue augue, aliquam non hendrerit ac, commodo vel nisi. 

## Lists

### Unordered - lists with a leading bullet
A list of items in which the order of the items does not explicitly matter.

You may use any of the following symbols to denote bullets for each list item:

```markdown
* valid bullet
- valid bullet
+ valid bullet
```

For example

``` markdown
* Lorem ipsum dolor sit amet
* Consectetur adipiscing elit
* Integer molestie lorem at massa
* Facilisis in pretium nisl aliquet
* Nulla volutpat aliquam velit
  - Phasellus iaculis neque
  - Purus sodales ultricies
  - Vestibulum laoreet porttitor sem
  - Ac tristique libero volutpat at
+ Faucibus porta lacus fringilla vel
+ Aenean sit amet erat nunc
+ Eget porttitor lorem
```
Displays as:
+ Lorem ipsum dolor sit amet
+ Consectetur adipiscing elit
+ Integer molestie lorem at massa
+ Facilisis in pretium nisl aliquet
+ Nulla volutpat aliquam velit
  - Phasellus iaculis neque
  - Purus sodales ultricies
  - Vestibulum laoreet porttitor sem
  - Ac tristique libero volutpat at
+ Faucibus porta lacus fringilla vel
+ Aenean sit amet erat nunc
+ Eget porttitor lorem


### Ordered - lists that are numbered

A list of items in which the order of items has signifcance.

``` markdown
1. Lorem ipsum dolor sit amet
2. Consectetur adipiscing elit
3. Integer molestie lorem at massa
4. Facilisis in pretium nisl aliquet
5. Nulla volutpat aliquam velit
6. Faucibus porta lacus fringilla vel
7. Aenean sit amet erat nunc
8. Eget porttitor lorem
```
Displays as:
1. Lorem ipsum dolor sit amet
2. Consectetur adipiscing elit
3. Integer molestie lorem at massa
4. Facilisis in pretium nisl aliquet
5. Nulla volutpat aliquam velit
6. Faucibus porta lacus fringilla vel
7. Aenean sit amet erat nunc
8. Eget porttitor lorem

**TIP**: If you just use `1.` for each number, a numbered list will display. For example:
``` markdown
1. Lorem ipsum dolor sit amet
1. Consectetur adipiscing elit
1. Integer molestie lorem at massa
1. Facilisis in pretium nisl aliquet
1. Nulla volutpat aliquam velit
1. Faucibus porta lacus fringilla vel
1. Aenean sit amet erat nunc
1. Eget porttitor lorem
```
Displays as:
1. Lorem ipsum dolor sit amet
1. Consectetur adipiscing elit
1. Integer molestie lorem at massa
1. Facilisis in pretium nisl aliquet
1. Nulla volutpat aliquam velit
1. Faucibus porta lacus fringilla vel
1. Aenean sit amet erat nunc
1. Eget porttitor lorem


## Tables
Tables are created by adding pipes as dividers between each cell, and by adding a line of dashes (also separated by bars) beneath the header. Note that the pipes do not need to be vertically aligned.


``` markdown
| Option | Description |
| ------ | ----------- |
| data   | path to data files to supply the data that will be passed into templates. |
| engine | engine to be used for processing templates. Handlebars is the default. |
| ext    | extension to be used for dest files. |
```

Displays as:  

| Option | Description |
| ------ | ----------- |
| data   | path to data files to supply the data that will be passed into templates. |
| engine | engine to be used for processing templates. Handlebars is the default. |
| ext    | extension to be used for dest files. |



### Right aligned text

Adding a colon on the right side of the dashes below any heading will right align text for that column.

``` markdown
| Option | Description |
| ------:| -----------:|
| data   | path to data files to supply the data that will be passed into templates. |
| engine | engine to be used for processing templates. Handlebars is the default. |
| ext    | extension to be used for dest files. |
```

Displays as:

| Option | Description |
| ------:| -----------:|
| data   | path to data files to supply the data that will be passed into templates. |
| engine | engine to be used for processing templates. Handlebars is the default. |
| ext    | extension to be used for dest files. |

## Links

### Basic link
A simple link to web page can be added by placing the URL address between parenthesis.
``` markdown
(http://assemble.io)
```
Displays as:

(http://assemble.io)

### Link with the title of the page
The preferred title goes between the square brackets before the URL address between the parenthesis.
``` markdown
[Assemble](http://assemble.io)
```
Displays as:

[Assemble](http://assemble.io)
### Link with the title of the page in a pop up box or tooltip

``` markdown
[Upstage](https://github.com/upstage/ "Visit Upstage!")
```

Displays as (hover over the link, there should be a tooltip):

[Upstage](https://github.com/upstage/ "Visit Upstage!")


### Named Anchors

Named anchors enable you to jump to the specified anchor point on the same page. For example, each of these chapters:

```markdown
### Table of Contents
  * [Chapter 1](#chapter-1)
  * [Chapter 2](#chapter-2)
  * [Chapter 3](#chapter-3)
```
Displays as:

### Table of Contents
  * [Chapter 1](#chapter-1)
  * [Chapter 2](#chapter-2)
  * [Chapter 3](#chapter-3)

## Images
Images have a similar syntax to links but include a preceding exclamation point. **Do not change the link information for images.**

``` markdown
![](http://cdn.door43.org/ta/jpg/vocabulary/we_us_inclusive.jpg)
```

Displays as:

![](http://cdn.door43.org/ta/jpg/vocabulary/we_us_inclusive.jpg)


## Code

### Inline code
Wrap inline snippets of code with `` ` ``.

For example, `<section></section>` should be wrapped as "inline".

``` html
For example, `<section></section>` should be wrapped as "inline".
```


### Indented code

Or indent several lines of code by at least four spaces, as in:

``` js
    // Some comments
    line 1 of code
    line 2 of code
    line 3 of code
```

    // Some comments
    line 1 of code
    line 2 of code
    line 3 of code
